@@ -10,13 +10,12 @@ use version;
 
 use Exporter qw/ import /;
 
-# use AutoLoader;
 use Carp;
 use File::Spec::Functions qw/ file_name_is_absolute /;
 use Module::Load 0.10;
 use Module::Loaded;
 
-our $VERSION = 'v3.3.2';
+our $VERSION = 'v3.4.0';
 
 our %EXPORT_TAGS = (
     'all'     => [qw( hex2tuple tuple2hex all_schemes )],
@@ -34,30 +33,8 @@ sub VERSION {
 # duplicates (which sometimes occur when directories are repeated in
 # @INC or via symlinks).  The order does not matter.
 
-# If we use AutoLoader, these should be use vars() ?
-
 my %FoundSchemes = ();
 
-# Since 2.10_02, we've added autoloading color names to the object-
-# oriented interface.
-
-our $AUTOLOAD;
-
-sub AUTOLOAD {
-    $AUTOLOAD =~ /^(.*:)*([\w\_]+)$/;
-    my $name = $2;
-    my $hex = ( my $self = $_[0] )->FETCH($name);
-    if ( defined $hex ) {
-        return $hex;
-    }
-    else {
-        croak "No method or color named $name";
-
-        # $AutoLoader::AUTOLOAD = $AUTOLOAD;
-        # goto &AutoLoader::AUTOLOAD;
-    }
-}
-
 sub _load {
     while ( my $module = shift ) {
         unless ( is_loaded($module) ) {
@@ -255,9 +232,6 @@ sub DESTROY {
     delete $self->{_iterator};
 }
 
-sub UNTIE {    # stub to avoid AUTOLOAD
-}
-
 BEGIN {
     no strict 'refs';
     *STORE  = \&_readonly_error;
@@ -382,7 +356,7 @@ Graphics::ColorNames - defines RGB values for common color names
 
 =head1 VERSION
 
-version v3.3.2
+version v3.4.0
 
 =head1 SYNOPSIS
 
@@ -485,13 +459,7 @@ C<RRGGBB> will return itself:
 
 =head2 autoloaded color name methods
 
-An autoloading interface was added in v2.11:
-
-  $po->green; # same as $po->rgb('green');
-
-Method names are case-insensitive, and underscores are ignored.
-
-This is deprecated, and will be removed in a future version.
+Autoloaded color name methods were removed in v3.4.0.
 
 =head2 C<load_scheme>
 
@@ -582,6 +550,37 @@ Since version 1.03, C<NamesRgbTable> may also return a code reference:
 
 See L<Graphics::ColorNames::GrayScale> for an example.
 
+=head1 ROADMAP
+
+The following changes are planned in the future:
+
+=over 4
+
+=item *
+
+Support for Perl versions earlier than 5.10 will be removed sometime
+in 2019.
+
+=item *
+
+The tied interface will be removed, but implemented in a separate
+module for users that wish to use it.
+
+=item *
+
+The namespace for color schemes will be moved to the
+C<Graphics::ColorNames::Schemes> but optios will be added to use the
+existing scheme.
+
+This will allow modules to be named like C<Graphics::ColorNames::Tied>
+without being confused for color schemes.
+
+=item *
+
+This module will be rewritten to be a L<Moo>-based class.
+
+=back
+
 =head1 SEE ALSO
 
 L<Color::Library> provides an extensive library of color schemes. A notable
